# upstream recommendations, https://www.cryptopp.com/wiki/Link_Time_Optimization
%define _lto_cflags %{nil}

%global v_tag %%(echo %{version} | sed 's/\\./_/g')
%global v_file %%(echo %{version} | sed 's/\\.//g')

Summary:        C++ class library of cryptographic schemes
Name:           cryptopp
Version:        8.8.0
Release:        1%{?dist}
License:        Boost
URL:            https://www.cryptopp.com
Source0:        %{url}/cryptopp%{v_file}.zip
Source1:        https://github.com/noloader/cryptopp-autotools/releases/download/CRYPTOPP_%{v_tag}/cryptopp-autotools%{v_file}.zip

# <major>+<minor>:<patch>:<minor> (this is confusing -_-)
Patch3000:      fix-autotools-version-info.patch
# fix "undefined reference to `AdhocTest'" when linking to the so
Patch3001:      remove-adhoc.patch

BuildRequires:  make gcc gcc-c++ libtool automake
BuildRequires:  bash coreutils findutils glibc-common
BuildRequires:  doxygen dos2unix
Provides:       pycryptopp = 0.7


%description
Crypto++ Library is a free C++ class library of cryptographic schemes.
See http://www.cryptopp.com/ for a list of supported algorithms.

%package devel
Summary:        Header files and development documentation for %{name}
Requires:       %{name} = %{version}-%{release}

%description devel
This package contains the header files and development documentation for %{name}.

%package static
Summary:        Static libraries for %{name}
Requires:       %{name}-devel = %{version}-%{release}

%description static
This package contains static libraries for %{name}.

%prep
%autosetup -c -p1 -a 1
find . -type f -name "*.zip" -exec rm "{}" \;
dos2unix License.txt Readme.txt
find . -not -type d -exec file "{}" ";" -print0 | grep -z CRLF | cut -d':' -z -f1 | xargs -0 dos2unix

%build
autoreconf -vi
# upstream recommends -O3, define NDEBUG to prevent sensitive data leaking on crash
export CXXFLAGS="$(echo "%{optflags}" | sed -e 's/-O2//') -O3 -DNDEBUG"
%configure
%make_build all-am docs

%install
%make_install

rm %{buildroot}%{_bindir}/cryptest
rm -rf %{buildroot}%{_datadir}/%{name}/
rm %{buildroot}%{_libdir}/lib*.la

mkdir -p %{buildroot}%{_libdir}/pkgconfig
install -p -m 0644 libcryptopp.pc %{buildroot}%{_libdir}/pkgconfig/libcryptopp.pc

%check
./cryptest v

%files
%{_libdir}/libcryptopp.so.8*
%doc Readme.txt
%license License.txt

%files devel
%doc html-docs/*
%{_includedir}/cryptopp
%{_libdir}/libcryptopp.so
%{_libdir}/pkgconfig/libcryptopp.pc

%files static
%{_libdir}/libcryptopp.a

%changelog
* Thu Oct 26 2023 Wang Guodong <gordonwwang@tencent.com> - 8.8.0-1
- initial build
